==> jc-1.4.0.tar.gz: java/rmi/server/ServerNotActiveException.h <==
// public class java.rmi.server.ServerNotActiveException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 7833a7205f5bcb7b java_rmi_server_ServerNotActiveException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_rmi_server_ServerNotActiveException_H_
#define _JC_java_rmi_server_ServerNotActiveException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_server_ServerNotActiveException$sub_refs	_jc_java_rmi_server_ServerNotActiveException$sub_refs;
typedef struct _jc_java_rmi_server_ServerNotActiveException$sub_nonrefs	_jc_java_rmi_server_ServerNotActiveException$sub_nonrefs;
typedef struct _jc_java_rmi_server_ServerNotActiveException$refs	_jc_java_rmi_server_ServerNotActiveException$refs;
typedef struct _jc_java_rmi_server_ServerNotActiveException$nonrefs	_jc_java_rmi_server_ServerNotActiveException$nonrefs;
typedef struct _jc_java_rmi_server_ServerNotActiveException$object	_jc_java_rmi_server_ServerNotActiveException$object;

typedef struct _jc_java_rmi_server_ServerNotActiveException$fields_struct	_jc_java_rmi_server_ServerNotActiveException$fields_struct;
typedef const struct _jc_java_rmi_server_ServerNotActiveException$vmethods	_jc_java_rmi_server_ServerNotActiveException$vmethods;
typedef const struct _jc_java_rmi_server_ServerNotActiveException$vtable	_jc_java_rmi_server_ServerNotActiveException$vtable;
typedef const struct _jc_java_rmi_server_ServerNotActiveException$vtype	_jc_java_rmi_server_ServerNotActiveException$vtype;

// Class fields structure
struct _jc_java_rmi_server_ServerNotActiveException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_server_ServerNotActiveException$fields_struct _jc_java_rmi_server_ServerNotActiveException$class_fields;

// Constructors
extern void _jc_java_rmi_server_ServerNotActiveException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_ServerNotActiveException$object *);
extern void _jc_java_rmi_server_ServerNotActiveException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_server_ServerNotActiveException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_rmi_server_ServerNotActiveException$vmethods {
};

// Vtable
struct _jc_java_rmi_server_ServerNotActiveException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_rmi_server_ServerNotActiveException$vmethods	java_rmi_server_ServerNotActiveException;
};

// Vtype
struct _jc_java_rmi_server_ServerNotActiveException$vtype {
	_jc_type			type;
	_jc_java_rmi_server_ServerNotActiveException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_ServerNotActiveException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_ServerNotActiveException$refs {
    _jc_java_rmi_server_ServerNotActiveException$sub_refs	java_rmi_server_ServerNotActiveException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_ServerNotActiveException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_ServerNotActiveException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_rmi_server_ServerNotActiveException$sub_nonrefs	java_rmi_server_ServerNotActiveException;
};

// Object instance structure
struct _jc_java_rmi_server_ServerNotActiveException$object {
	_jc_java_rmi_server_ServerNotActiveException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_ServerNotActiveException$vtype	*vtype;
	_jc_java_rmi_server_ServerNotActiveException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_ServerNotActiveException$vtype _jc_java_rmi_server_ServerNotActiveException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_ServerNotActiveException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_ServerNotActiveException$class_object;

#endif	/* _JC_java_rmi_server_ServerNotActiveException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/ServerNotActiveException.h <==
// public class java.rmi.server.ServerNotActiveException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 7833a7205f5bcb7b java_rmi_server_ServerNotActiveException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_rmi_server_ServerNotActiveException_H_
#define _JC_java_rmi_server_ServerNotActiveException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_server_ServerNotActiveException$sub_refs	_jc_java_rmi_server_ServerNotActiveException$sub_refs;
typedef struct _jc_java_rmi_server_ServerNotActiveException$sub_nonrefs	_jc_java_rmi_server_ServerNotActiveException$sub_nonrefs;
typedef struct _jc_java_rmi_server_ServerNotActiveException$refs	_jc_java_rmi_server_ServerNotActiveException$refs;
typedef struct _jc_java_rmi_server_ServerNotActiveException$nonrefs	_jc_java_rmi_server_ServerNotActiveException$nonrefs;
typedef struct _jc_java_rmi_server_ServerNotActiveException$object	_jc_java_rmi_server_ServerNotActiveException$object;

typedef struct _jc_java_rmi_server_ServerNotActiveException$fields_struct	_jc_java_rmi_server_ServerNotActiveException$fields_struct;
typedef const struct _jc_java_rmi_server_ServerNotActiveException$vmethods	_jc_java_rmi_server_ServerNotActiveException$vmethods;
typedef const struct _jc_java_rmi_server_ServerNotActiveException$vtable	_jc_java_rmi_server_ServerNotActiveException$vtable;
typedef const struct _jc_java_rmi_server_ServerNotActiveException$vtype	_jc_java_rmi_server_ServerNotActiveException$vtype;

// Class fields structure
struct _jc_java_rmi_server_ServerNotActiveException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_server_ServerNotActiveException$fields_struct _jc_java_rmi_server_ServerNotActiveException$class_fields;

// Constructors
extern void _jc_java_rmi_server_ServerNotActiveException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_ServerNotActiveException$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_ServerNotActiveException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_server_ServerNotActiveException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_server_ServerNotActiveException$vmethods {
};

// Vtable
struct _jc_java_rmi_server_ServerNotActiveException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_rmi_server_ServerNotActiveException$vmethods	java_rmi_server_ServerNotActiveException;
};

// Vtype
struct _jc_java_rmi_server_ServerNotActiveException$vtype {
	_jc_type			type;
	_jc_java_rmi_server_ServerNotActiveException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_ServerNotActiveException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_ServerNotActiveException$refs {
    _jc_java_rmi_server_ServerNotActiveException$sub_refs	java_rmi_server_ServerNotActiveException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_ServerNotActiveException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_ServerNotActiveException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_rmi_server_ServerNotActiveException$sub_nonrefs	java_rmi_server_ServerNotActiveException;
};

// Object instance structure
struct _jc_java_rmi_server_ServerNotActiveException$object {
	_jc_java_rmi_server_ServerNotActiveException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_ServerNotActiveException$vtype	*vtype;
	_jc_java_rmi_server_ServerNotActiveException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_ServerNotActiveException$vtype _jc_java_rmi_server_ServerNotActiveException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_ServerNotActiveException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_ServerNotActiveException$class_object;

#endif	/* _JC_java_rmi_server_ServerNotActiveException_H_ */
